MethodChannelNtfy class
An implementation of NtfyPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- NtfyPlatform
- MethodChannelNtfy
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ Stream<
String> -
no setteroverride
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
String url, String topic, {String? auth}) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited