NtfyPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NtfyPlatform
Implementers

Constructors

NtfyPlatform()
Constructs a NtfyPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
messages Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(String url, String topic, {String? auth}) Future<void>
toString() String
A string representation of this object.
inherited
unsubscribe() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NtfyPlatform
The default instance of NtfyPlatform to use.
getter/setter pair